##
##  gpgme.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gpgme
Summary:      GnuPG Made Easy
URL:          http://www.gnupg.org/gpgme.html
Vendor:       Marcus Brinkmann
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Cryptography
License:      GPL
Version:      1.23.2
Release:      20231130

#   list of sources
Source0:      ftp://ftp.gnupg.org/gcrypt/gpgme/gpgme-%{version}.tar.bz2
Patch0:       gpgme.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  gnupg, gpg-error, libassuan
PreReq:       gnupg, gpg-error, libassuan

%description
    GnuPG Made Easy (GPGME) is a C library designed to make access to
    GnuPG easier for applications. It provides a High-Level Crypto API
    for encryption, decryption, signing, signature verification and key
    management. Currently it uses GnuPG as its backend but the API isn't
    restricted to this engine.

%track
    prog gpgme = {
        version   = %{version}
        url       = ftp://ftp.gnupg.org/gcrypt/gpgme/
        regex     = gpgme-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;$gpg_error_config_args --version;--version;' \
        configure
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --with-gpg-error-prefix=%{l_prefix} \
        --without-pth \
        --with-gpg=%{l_prefix}/bin/gpg \
        --with-libassuan-prefix=%{l_prefix} \
        --disable-shared
    %{l_shtool} subst \
        -e 's;tests = tests;tests =;' \
        Makefile
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/common-lisp
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

